__all__ = [ "project" ]

project = {
    "name"         : "slixmpp-omemo",
    "description"  : "Slixmpp OMEMO plugin",
    "url"          : "https://github.com/Syndace/slixmpp-omemo",
    "year"         : "2024",
    "author"       : "Tim Henkes (Syndace)",
    "author_email" : "me@syndace.dev",
    "categories"   : [
        "Topic :: Communications :: Chat",
        "Topic :: Internet :: XMPP",
        "Topic :: Security :: Cryptography",
        "Topic :: Software Development :: Libraries :: Python Modules"
    ]
}
